@@ -4,7 +4,7 @@ import math
 from decimal import Decimal
 
 
-class PRPlot(ms=30, lw=3, name_plot=None, x_name="X", y_name="Y",save_name="Plot"):
+class PRPlot():
     def __int__(self, ms=30, lw=3, name_plot=None, x_name="X", y_name="Y",save_name="Plot"):
         self.ms = ms
         self.lw = lw
@@ -46,11 +46,11 @@ class PRPlot(ms=30, lw=3, name_plot=None, x_name="X", y_name="Y",save_name="Plot
             lis.append(i)
         return lis
 
-    def main(self, ref, predict, save):
-        # mpl.rc('font', family='Times New Roman')
+    def main(self, ref, predict, save,ms=30, lw=3, name_plot=None, x_name="X", y_name="Y",save_name="Plot"):
+        mpl.rc('font', family='Times New Roman')
         fig, axs = plt.subplots(figsize=(12, 7))
-        axs.plot(ref, predict, ".", color="red", ms=self.ms)
-        axs.plot(ref, ref, color="blue", lw=self.lw)
+        axs.plot(ref, predict, ".", color="red", ms=ms)
+        axs.plot(ref, ref, color="blue", lw=lw)
 
         lis_x, lis_x_num = self.ax(ref)
         lis_y, lis_y_num = self.ax(self.n_dat(ref,predict))
@@ -58,10 +58,10 @@ class PRPlot(ms=30, lw=3, name_plot=None, x_name="X", y_name="Y",save_name="Plot
         axs.set_xticks(lis_x_num)
         axs.set_yticks(lis_y_num)
 
-        axs.set_ylabel(self.y_name, fontsize=25, labelpad=8)
+        axs.set_ylabel(y_name, fontsize=25, labelpad=8)
         axs.grid(color="black", linewidth=0.7)
-        axs.set_xlabel(self.x_name, fontsize=25, labelpad=15)
-        axs.set_title(self.name_plot, fontsize=28, loc="center", pad=15)
+        axs.set_xlabel(x_name, fontsize=25, labelpad=15)
+        axs.set_title(name_plot, fontsize=28, loc="center", pad=15)
         axs.tick_params(which='major', length=10, width=2)
 
         axs.set_xticklabels(lis_x, fontsize=20)
@@ -71,8 +71,8 @@ class PRPlot(ms=30, lw=3, name_plot=None, x_name="X", y_name="Y",save_name="Plot
         axs.get_yaxis().set_tick_params(direction='in')
 
         if save:
-            plt.savefig(self.save_name+'.png', format='png', dpi=300)
-            plt.savefig(self.save_name+".svg", format="svg")
+            plt.savefig(save_name+'.png', format='png', dpi=300)
+            plt.savefig(save_name+".svg", format="svg")
         plt.show()
         return 0
 
